@@ -1,4 +1,3 @@
-import types
 import warnings
 import functools
 
@@ -49,32 +48,13 @@ class _Registry(dict):
         self[override_class] = override_class
 
 
-class overridefunc(object):
-    '''decorator for overriding a function'''
-    def __init__(self, func):
-        if not hasattr(func, '__info__'):
-            raise TypeError("func must be an gi function")
-        from ..importer import modules
-        module_name = func.__module__.rsplit('.', 1)[-1]
-        self.module = modules[module_name]._introspection_module
-
-    def __call__(self, func):
-        def wrapper(*args, **kwargs):
-            return func(*args, **kwargs)
-        wrapper.__name__ = func.__name__
-        setattr(self.module, func.__name__, wrapper)
-        return wrapper
-
 registry = _Registry()
 
 
 def override(type_):
     '''Decorator for registering an override'''
-    if isinstance(type_, types.FunctionType):
-        return overridefunc(type_)
-    else:
-        registry.register(type_)
-        return type_
+    registry.register(type_)
+    return type_
 
 
 def deprecated(fn, replacement):
@@ -85,3 +65,25 @@ def deprecated(fn, replacement):
                       PyGIDeprecationWarning, stacklevel=2)
         return fn(*args, **kwargs)
     return wrapped
+
+
+def strip_boolean_result(method, exc_type=None, exc_str=None, fail_ret=None):
+    '''Translate method's return value for stripping off success flag.
+
+    There are a lot of methods which return a "success" boolean and have
+    several out arguments. Translate such a method to return the out arguments
+    on success and None on failure.
+    '''
+    @functools.wraps(method)
+    def wrapped(*args, **kwargs):
+        ret = method(*args, **kwargs)
+        if ret[0]:
+            if len(ret) == 2:
+                return ret[1]
+            else:
+                return ret[1:]
+        else:
+            if exc_type:
+                raise exc_type(exc_str or 'call failed')
+            return fail_ret
+    return wrapped
