@@ -353,7 +353,7 @@ _pygi_closure_convert_arguments (GICallableInfo *callable_info, void **args,
                     arg = (GIArgument*) g_args[i].v_pointer;
                 
                 if (g_type_info_get_tag (&arg_type) == GI_TYPE_TAG_ARRAY)
-                    arg->v_pointer = _pygi_argument_to_array (arg, (GIArgument **) args, 
+                    arg->v_pointer = _pygi_argument_to_array (arg, (GIArgument **) args, NULL,
                                                               callable_info, &arg_type, &free_array);
 
                 value = _pygi_argument_to_object (arg, &arg_type, transfer);
@@ -508,8 +508,6 @@ _pygi_closure_handle (ffi_cif *cif,
 end:
     g_free (out_args);
 
-    PyGILState_Release (state);
-
     /* Now that the closure has finished we can make a decision about how
        to free it.  Scope call gets free'd at the end of wrap_g_function_info_invoke.
        Scope notified will be freed when the notify is called.
@@ -532,6 +530,8 @@ end:
             g_error ("Invalid scope reached inside %s.  Possibly a bad annotation?",
                      g_base_info_get_name (closure->info));
     }
+
+    PyGILState_Release (state);
 }
 
 void _pygi_invoke_closure_free (gpointer data)
